''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''
' ___PageEmailer Class___
'
' Author: Alex Papadimoulis (alex@papadimoulis.com)
' History
'  040917  AP  Move class into /includes folder
' 
' This class allows the contents of a given URL to be sent via email.
' Content is extracted from the URL, embedding external resources (such
' as images and stylesheets) into a MIME-encoded message. The subject can
' be automatically extracted from the page Title.

' This operates mostly by wrapping the CDOSYS Message class. The CDO.Message's 
' IConfiguration is exposed with a much more friendly Configuration property, 
' which allows for server configuration when the default configuration won't work.
'
' Sample code for consumption of class:
'
'   dim msg : set msg = New PageEmailer
'   msg.Subject = "Optional Subject"
'   msg.send "joe@example.com", "/templates/notify.asp"
'
'   NOTE: The third parameter of Send (URL) can be an explicit, absoulte, or relative URL.
'   A URL is relative to the consuming class, not this VB code file. 

Class PageEmailer

	''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''
	' Configuration
	''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''
	Private Sub InitializeDefaultValues
		From = """MyAdventureGame.com"" <notify-noreply@myadventuregame.com>"
		
		'See http://schemas.microsoft.com/cdo/configuration/ for all options
		Configuration("SmtpServer") = "localhost"
		'Configuration("SendUsername") = ""
		'Configuration("SendPassword") = ""
		Configuration("UrlGetLatestVersion") = 1
	End Sub
	
	''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''
	' Properties
	''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''
	Private m_CdoMessage
	Public Property Get CdoMessage : Set CdoMessage = m_CdoMessage : End Property
	
	Public Property Get From : From = CdoMessage.From : End Property
	Public Property Let From(val) : CdoMessage.From = val : End Property

	Private Property Get Configuration(fld)
		Configuration = CdoMessage.Configuration.Fields("http://schemas.microsoft.com/cdo/configuration/" & lcase(fld)) 
	End Property
	Private Property Let Configuration(fld,val)
		CdoMessage.Configuration.Fields("http://schemas.microsoft.com/cdo/configuration/" & lcase(fld)) = val
	End Property
	
	Public Subject
	
	''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''
	' Methods
	''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''
	Public Sub Send( [To], Url )
		Dim AbsUrl, Port
		If Left(Url,4) = "http"  Then 
			AbsUrl = Url
		Else
			If Left(Url,1) = "/" Then
				AbsUrl = "http://" & Request.ServerVariables("SERVER_NAME") & ":" & Request.ServerVariables("SERVER_PORT") & Url
			Else
				AbsUrl = Request.ServerVariables("PATH_INFO")
				AbsUrl = "http://" & Request.ServerVariables("SERVER_NAME") & ":" & Request.ServerVariables("SERVER_PORT") & _
					Left(AbsUrl, InstrRev(AbsUrl,"/")) & Url
			End If 
		End If
		
		With CdoMessage
			.Bcc = [To] 
			.CreateMHTMLBody AbsUrl
			If IsNull(Subject) Then
				Dim bod : bod = LCase(.HtmlBody)
				Dim tOpen : tOpen = Instr(bod,"<title>")
				Dim tClos : tClos = Instr(bod,"</title>")
				If tOpen>=0 And tOpen<tClos Then 
					.Subject = Mid(.HtmlBody, tOpen + 7, tClos - tOpen - 7 ) 
				Else 
					.Subject="(no subject)"
				End If
			Else
				.Subject=Subject
			End If			
			.Send
		End With
	End Sub
		
	Sub Class_Initialize
		Set m_CdoMessage = Server.CreateObject("CDO.Message")
		InitializeDefaultValues
		CdoMessage.Configuration.Fields.Update
		Subject = null
	End Sub
End Class